@@ -6,7 +6,7 @@
 #
 # Purpose: This is the installation script for fwsnort.
 #
-# Copyright (C) 2003-2011 Michael Rash (mbr@cipherdyne.org)
+# Copyright (C) 2003-2007 Michael Rash (mbr@cipherdyne.org)
 #
 # License (GNU Public License):
 #
@@ -17,14 +17,16 @@
 #
 #    You should have received a copy of the GNU General Public License
 #    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
+#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 #    USA
 #
 # TODO:
-#   - Write the uninstall() routine.
+#   - Write the uninstall() routine. :)
 #
 #######################################################################
 #
+# $Id: install.pl 514 2010-01-05 03:39:53Z mbr $
+#
 
 use Cwd;
 use IO::Socket;
@@ -36,8 +38,7 @@ use strict;
 #========================= config ========================
 my $fwsnort_conf_file = 'fwsnort.conf';
 
-my $sbin_dir     = '/usr/sbin';
-my $install_root = '/';
+my $sbin_dir    = '/usr/sbin';
 
 my $update_website = 'www.emergingthreats.net';
 
@@ -53,9 +54,9 @@ my %config = ();
 
 ### map perl modules to versions
 my %required_perl_modules = (
-    'NetAddr::IP' => {
+    'Net::IPv4Addr' => {
         'force-install' => 0,
-        'mod-dir' => 'NetAddr-IP'
+        'mod-dir' => 'Net-IPv4Addr'
     },
     'IPTables::Parse' => {
         'force-install' => 1,
@@ -63,14 +64,10 @@ my %required_perl_modules = (
     }
 );
 
-### rules update link
-my $rules_url = 'http://rules.emergingthreats.net/open/snort-2.9.0/emerging-all.rules';
-
 ### establish some defaults
 my $uninstall = 0;
 my $skip_module_install   = 0;
 my $cmdline_force_install = 0;
-my $install_test_dir = 0;
 my $force_mod_re = '';
 my $exclude_mod_re = '';
 my $deps_dir = 'deps';
@@ -96,9 +93,7 @@ Getopt::Long::Configure('no_ignore_case');
     'Force-mod-regex=s' => \$force_mod_re, ### force specific mod install with regex
     'Exclude-mod-regex=s' => \$exclude_mod_re, ### exclude a particular perl module
     'Skip-mod-install'  => \$skip_module_install,
-    'rules-url=s' => \$rules_url,
     'uninstall' => \$uninstall, ### uninstall fwsnort
-    'install-test-dir'  => \$install_test_dir,
     'LC_ALL=s'  => \$locale,
     'no-LC_ALL' => \$no_locale,
     'help'      => \$help
@@ -109,14 +104,6 @@ Getopt::Long::Configure('no_ignore_case');
 ### set LC_ALL env variable
 $ENV{'LC_ALL'} = $locale unless $no_locale;
 
-### make a copy of the original fwsnort.conf file and restore at the end
-copy $fwsnort_conf_file, "${fwsnort_conf_file}.orig" or die "[*] Could not ",
-    "copy $fwsnort_conf_file -> $fwsnort_conf_file.orig";
-
-if ($install_test_dir) {
-    $install_root = getcwd() . '/test/fwsnort-install';
-}
-
 &import_config();
 
 $force_mod_re = qr|$force_mod_re| if $force_mod_re;
@@ -138,14 +125,6 @@ if ($uninstall) {
 } else {
     &install()
 }
-
-### restore the original fwsnort.conf file (this is just the local one in the
-### sources directory).
-if (-e "${fwsnort_conf_file}.orig") {
-    unlink $fwsnort_conf_file if -e $fwsnort_conf_file;
-    move "${fwsnort_conf_file}.orig", $fwsnort_conf_file;
-}
-
 exit 0;
 #===================== end main ===================
 
@@ -154,10 +133,12 @@ sub install() {
         "sources directory." unless -e 'fwsnort' and -e 'fwsnort.conf';
 
     unless (-d $config{'CONF_DIR'}) {
-        &full_mkdir($config{'CONF_DIR'}, 0500);
+        print "[+] mkdir $config{'CONF_DIR'}\n";
+        mkdir $config{'CONF_DIR'}, 0500;
     }
     unless (-d $config{'RULES_DIR'}) {
-        &full_mkdir($config{'RULES_DIR'}, 0500);
+        print "[+] mkdir $config{'RULES_DIR'}\n";
+        mkdir $config{'RULES_DIR'}, 0500;
     }
 
     ### install perl modules
@@ -177,7 +158,7 @@ sub install() {
                 or die "[*] Could not move emerging-all.rules -> ",
                 "emerging-all.rules.tmp";
         }
-        system "$cmds{'wget'} $rules_url";
+        system "$cmds{'wget'} http://$update_website/rules/emerging-all.rules";
         if (-e 'emerging-all.rules') {  ### successful download
             unlink 'emerging-all.rules.tmp';
         } else {
@@ -232,7 +213,7 @@ sub install() {
 
     print "\n========================================================\n",
         "\n[+] fwsnort will generate an iptables script located at:\n",
-        "    /var/lib/fwsnort.sh when executed.\n",
+        "    /etc/fwsnort/fwsnort.sh when executed.\n",
         "\n[+] fwsnort has been successfully installed!\n\n";
 
     return;
@@ -292,7 +273,8 @@ sub install_perl_module() {
     if ($install_module) {
         unless (-d $config{'LIBS_DIR'}) {
             print "[+] Creating $config{'LIBS_DIR'}\n";
-            &full_mkdir($config{'LIBS_DIR'}, 0755);
+            mkdir $config{'LIBS_DIR'}, 0755
+                or die "[*] Could not mkdir $config{'LIBS_DIR'}: $!";
         }
         print "[+] Installing the $mod_name $version perl " .
             "module in $config{'LIBS_DIR'}/\n";
@@ -382,7 +364,7 @@ sub install_manpage() {
             }
         }
     }
-    &full_mkdir($mpath, 0755);
+    mkdir $mpath, 0755 unless -d $mpath;
     my $mfile = "${mpath}/${manpage}";
     print "[+] Installing $manpage man page as $mfile\n";
     copy $manpage, $mfile or die "[*] Could not copy $manpage to " .
@@ -396,7 +378,6 @@ sub install_manpage() {
 }
 
 sub query_get_emerging_threats_sigs() {
-    return 0 if $install_test_dir;
     my $ans = '';
     print "[+] Would you like to download the latest Snort rules from \n",
         "    http://$update_website/?\n";
@@ -430,31 +411,9 @@ sub import_config() {
     }
     close C;
 
-    ### see if the install root is the same as the default in fwsnort.conf and
-    ### update if not
-    if ($install_root ne '/') {
-        $install_root = getcwd() . "/$install_root"
-            unless $install_root =~ m|^/|;
-        $config{'INSTALL_ROOT'} = $install_root;
-        $sbin_dir = $config{'INSTALL_ROOT'} . $sbin_dir;
-
-        &put_var('INSTALL_ROOT', $install_root, $fwsnort_conf_file);
-    }
-
     ### resolve internal vars within variable values
     &expand_vars();
 
-    for my $dir ($install_root,
-            $sbin_dir,
-            $config{'LOG_DIR'},
-            $config{'LIB_DIR'},
-            $config{'STATE_DIR'},
-            $config{'QUEUE_RULES_DIR'},
-            $config{'ARCHIVE_DIR'},
-        ) {
-        &full_mkdir($dir, 0755) unless -d $dir;
-    }
-
     &required_vars();
 
     return;
@@ -479,11 +438,7 @@ sub expand_vars() {
                     die "[*] sub-ver $sub_var not allowed within same ",
                         "variable $var" if $sub_var eq $var;
                     if (defined $config{$sub_var}) {
-                        if ($sub_var eq 'INSTALL_ROOT' and $config{$sub_var} eq '/') {
-                            $val =~ s|\$$sub_var||;
-                        } else {
-                            $val =~ s|\$$sub_var|$config{$sub_var}|;
-                        }
+                        $val =~ s|\$$sub_var|$config{$sub_var}|;
                         $hr->{$var} = $val;
                     } else {
                         die "[*] sub-var \"$sub_var\" not defined in ",
@@ -497,24 +452,6 @@ sub expand_vars() {
     return;
 }
 
-sub put_var() {
-    my ($var, $value, $file) = @_;
-
-    open RF, "< $file" or die "[*] Could not open $file: $!";
-    my @lines = <RF>;
-    close RF;
-    open F, "> $file" or die "[*] Could not open $file: $!";
-    for my $line (@lines) {
-        if ($line =~ /^\s*$var\s+.*;/) {
-            printf F "%-24s%s;\n", $var, $value;
-        } else {
-            print F $line;
-        }
-    }
-    close F;
-    return;
-}
-
 sub required_vars() {
     my @required_vars = qw(
         CONF_DIR RULES_DIR ARCHIVE_DIR QUEUE_RULES_DIR LOG_DIR LIBS_DIR
@@ -554,7 +491,6 @@ sub check_commands() {
 }
 
 sub query_preserve_config() {
-    return 0 if $install_test_dir;
     my $ans = '';
     while ($ans ne 'y' && $ans ne 'n') {
         print "[+] Would you like to preserve the config from the\n",
@@ -619,23 +555,6 @@ sub preserve_config() {
     return;
 }
 
-sub full_mkdir() {
-    my ($dir, $perms) = @_;
-
-    my @dirs = split /\//, $dir;
-    my $path = $dirs[0];
-    shift @dirs;
-    for my $d (@dirs) {
-        next unless $d and $d =~ /\S/;
-        $path .= "/$d";
-        unless (-d $path) {
-            printf "[+] mkdir $path, %o\n", $perms;
-            mkdir $path, $perms or die "[*] Could not mkdir($path): $!";
-        }
-    }
-    return;
-}
-
 sub usage() {
     my $exit = shift;
     print <<_HELP_;
@@ -647,12 +566,6 @@ install.pl: [options]
                                      specific regular expression.
     -E, --Exclude-mod-regex <re>   - Exclude a perl module that matches this
                                      regular expression.
-    -S, --Skip-mod-install         - Skip installation of modules.
-    -r, --rules-url <url>          - Specify the URL to use for updating the
-                                     Emerging Threats rule set - the default is:
-                                     $rules_url
-    --install-test-dir             - Install fwsnort in test/fwsnort-install
-                                     for test suite.
     -u, --uninstall   - uninstall fwsnort
     -h, --help        - print help and exit
 _HELP_
